summaryrefslogtreecommitdiff
path: root/lisp/vc/vc-sccs.el
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>2014-11-22 05:21:09 -0500
committerEric S. Raymond <esr@thyrsus.com>2014-11-22 05:21:09 -0500
commit4fe5b7c0bbb77286ce2866c9237796d0587ce2a3 (patch)
tree9147a005c30d138e12885800c78d3f4a5a7b7bbb /lisp/vc/vc-sccs.el
parent354a07b57092b9231734a9d983d074bd4d542f62 (diff)
downloademacs-4fe5b7c0bbb77286ce2866c9237796d0587ce2a3.tar.gz
More movement of master-related code to vc-filewise.el.
Goes with my 2014-11-22 lisp/ChangeLog entry.
Diffstat (limited to 'lisp/vc/vc-sccs.el')
-rw-r--r--lisp/vc/vc-sccs.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/vc/vc-sccs.el b/lisp/vc/vc-sccs.el
index 780efc48e96..fc9c07277ae 100644
--- a/lisp/vc/vc-sccs.el
+++ b/lisp/vc/vc-sccs.el
@@ -75,7 +75,7 @@ If nil, use the value of `vc-diff-switches'. If t, use no switches."
:group 'vc-sccs)
;; This needs to be autoloaded because vc-sccs-registered uses it (via
;; vc-default-registered), and vc-hooks needs to be able to check
;; for a registered backend without loading every backend.
;;;###autoload
(defcustom vc-sccs-master-templates
@@ -112,7 +112,7 @@ For a description of possible values, see `vc-check-master-templates'."
;; every file that is visited.
;;;###autoload
(progn
-(defun vc-sccs-registered (f) (vc-default-registered 'SCCS f)))
+(defun vc-sccs-registered (f) (vc-master-registered 'SCCS f)))
(defun vc-sccs-state (file)
"SCCS-specific function to compute the version control state."
@@ -75,7 +75,7 @@ If nil, use the value of `vc-diff-switches'. If t, use no switches."
:group 'vc-sccs)
;; This needs to be autoloaded because vc-sccs-registered uses it (via
-;; vc-default-registered), and vc-hooks needs to be able to check
+;; vc-master-registered), and vc-hooks needs to be able to check
;; for a registered backend without loading every backend.
;;;###autoload